@@ -1,7 +1,7 @@
+use super::styles::colors::*;
+use super::styles::svgs::*;
+use super::widgets::*;
 use super::{message::Message, View};
-use crate::styles::colors::*;
-use crate::styles::svgs::*;
-use crate::widgets::*;
 use fltk::{enums::*, prelude::*, *};
 
 pub struct App {
@@ -16,8 +16,14 @@ impl App {
         std::panic::set_hook(Box::new(|info| {
             if let Some(s) = info.payload().downcast_ref::<&str>() {
                 if !s.contains("self.was_deleted") {
-                    fltk::dialog::message_default(&format!("{}", s));
+                    fltk::dialog::message_default(s);
                 }
+            } else if let Some(s) = info.payload().downcast_ref::<String>() {
+                if !s.contains("self.was_deleted") {
+                    fltk::dialog::message_default(s);
+                }
+            } else {
+                fltk::dialog::message_default(&format!("{:?}", info));
             }
         }));
         let a = app::App::default();
@@ -29,7 +35,12 @@ impl App {
         app::set_selection_color(r, g, b);
         misc::Tooltip::set_color(Color::from_rgb(0xFF, 0xFF, 0xF0));
         app::set_font_size(16);
-        if let Ok(f) = Font::load_font("Roboto-Medium.ttf") {
+        let temp = std::env::temp_dir().join("Roboto-Medium.ttf");
+        if !temp.exists() {
+            let bytes = include_bytes!("../../Roboto-Medium.ttf");
+            std::fs::write(&temp, bytes).ok();
+        }
+        if let Ok(f) = Font::load_font(temp) {
             Font::set_font(Font::Helvetica, &f);
         }
         let (s, r) = app::channel();
@@ -37,7 +48,7 @@ impl App {
             .with_size(800, 600)
             .with_label("sysinfo-gui");
         win.set_xclass("sysinfo");
-        let mut grp = group::Group::new(0, 0, 60, 600, None);
+        let mut grp = group::Group::default().with_size(60, 600);
         grp.set_frame(FrameType::FlatBox);
         grp.set_color(BLUE);
         let mut col = group::Pack::default()
